<a name="v0.2.0"></a>
## [v0.2.0](https://github.com/alexseitsinger/birdhouse_toolbox/compare/v0.1.0...v0.2.0) (2019-05-13)

### Bug Fixes
- fixes imports ([fb0b86f](https://github.com/alexseitsinger/birdhouse_toolbox/commit/fb0b86fcff6a272130f3f74f5793c2f94d5694ec))
- fixes imports ([11efbff](https://github.com/alexseitsinger/birdhouse_toolbox/commit/11efbffb222ffb0b56a802762452de172abf1c8a))
- fixes imports ([b2617a1](https://github.com/alexseitsinger/birdhouse_toolbox/commit/b2617a16b8ae9480fdcc4c297ddd8e9da836d9de))
- fixes imports ([75f02ef](https://github.com/alexseitsinger/birdhouse_toolbox/commit/75f02ef9d5e36e5c3016d5a941852026b19b2123))

### Code Refactoring
- adds options module ([7080f96](https://github.com/alexseitsinger/birdhouse_toolbox/commit/7080f966a0e1fd4009e24ebf342849c4cbb05f93))
- changes settings ([8751f74](https://github.com/alexseitsinger/birdhouse_toolbox/commit/8751f741937c6255e63d909d584ae3db5b5d0ec5))
- fixes order of vars ([1bc40a9](https://github.com/alexseitsinger/birdhouse_toolbox/commit/1bc40a9a894ae4a1c498f72ececfb6c3250e9657))
- imports subgroup ([f81d6c8](https://github.com/alexseitsinger/birdhouse_toolbox/commit/f81d6c8bb2d23132a23d7305ff45f2bf54d0917d))
- moves commands ([c0a0b2c](https://github.com/alexseitsinger/birdhouse_toolbox/commit/c0a0b2c7e7c8252eb782e8b1bcb0c23205575dbe))
- moves commands ([7207138](https://github.com/alexseitsinger/birdhouse_toolbox/commit/72071383915b4789d28e28e1ad1417a852a529f3))
- moves commands ([10b5a88](https://github.com/alexseitsinger/birdhouse_toolbox/commit/10b5a88a910e5f248e3240ea8a694bb5ff08bfe0))
- moves modules ([fa50e06](https://github.com/alexseitsinger/birdhouse_toolbox/commit/fa50e06da2c9fdb11fc6b21e8a5ae8f97608485f))
- moves options ([eb2b4ae](https://github.com/alexseitsinger/birdhouse_toolbox/commit/eb2b4ae48c2ff2c7ae0c9d65765b72b2d01ed5d7))


<a name="v0.1.0"></a>
## [v0.1.0](https://github.com/alexseitsinger/birdhouse_toolbox/compare/dd8ca18695758dccbb80d52d752a8cd66281b35d...v0.1.0) (2019-05-11)


